@@ -1,6 +1,6 @@
 package POE::Component::Resolver;
 BEGIN {
-  $POE::Component::Resolver::VERSION = '0.913';
+  $POE::Component::Resolver::VERSION = '0.914';
 }
 
 use warnings;
@@ -18,6 +18,16 @@ use Exporter;
 use base 'Exporter';
 our (@EXPORT_OK) = qw(AF_INET AF_INET6);
 
+# Determine Perl's location, per perldoc perlvar's treatment of $^X.
+
+use Config;
+my $perl_path = $Config{perlpath};
+if ($^O ne 'VMS') {
+	$perl_path .= $Config{_exe} unless (
+		$perl_path =~ /$Config{_exe}$/i
+	);
+}
+
 # Plain Perl constructor.
 
 sub new {
@@ -57,7 +67,7 @@ sub new {
 		}
 		else {
 			$sidecar_program = [
-				$^X,
+				$perl_path,
 				(map { "-I$_" } @INC),
 				'-MPOE::Component::Resolver::Sidecar',
 				'-e', 'POE::Component::Resolver::Sidecar->main()'
@@ -436,7 +446,7 @@ POE::Component::Resolver - A non-blocking getaddrinfo() resolver
 
 =head1 VERSION
 
-version 0.913
+version 0.914
 
 =head1 SYNOPSIS
 
